#
# spec file for package python-pysaml2
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global modname pysaml2
Name:           python-pysaml2
Version:        4.6.5
Release:        2.1
Summary:        Python implementation of SAML Version 2 to be used in a WSGI environment
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/IdentityPython/pysaml2
Source:         https://github.com/IdentityPython/pysaml2/archive/v%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Paste
Requires:       python-cryptography >= 1.4
Requires:       python-defusedxml
Requires:       python-future
Requires:       python-pyOpenSSL
Requires:       python-python-dateutil
Requires:       python-pytz
Requires:       python-repoze.who
Requires:       python-requests >= 1.0.0
Requires:       python-six
Requires:       python-zope.interface
BuildArch:      noarch
BuildRequires:  %{python_module Paste}
BuildRequires:  %{python_module cryptography >= 1.4}
BuildRequires:  %{python_module defusedxml}
BuildRequires:  %{python_module future}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pyOpenSSL}
BuildRequires:  %{python_module pymongo}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module repoze.who}
BuildRequires:  %{python_module requests >= 1.0.0}
BuildRequires:  %{python_module responses}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module zope.interface}
# This is needed as xmlsec itself does not pull any backend by default
# Will be fixed in future xmlsec releases
BuildRequires:  libxmlsec1-openssl1
BuildRequires:  python2-gdbm
BuildRequires:  python3-dbm
BuildRequires:  xmlsec1
%python_subpackages

%description
PySAML2 is a pure python implementation of SAML2.
It contains all necessary pieces for building a
SAML2 service provider or an identity provider.

%prep
%setup -q -n %{modname}-%{version}
# delete shebang of files not in executable path
find src/ -name '*.py' -print0 | xargs -0 sed -i '1s/#!.*$//'
# remove tests that poll internet
rm -f tests/test_30_mdstore*.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} py.test-%{$python_bin_suffix}

%files %{python_files}
%license LICENSE
%doc README.rst CHANGELOG.md
%python3_only %{_bindir}/make_metadata.py
%python3_only %{_bindir}/parse_xsd2.py
%python3_only %{_bindir}/mdexport.py
%python3_only %{_bindir}/merge_metadata.py
%{python_sitelib}/*

%changelog
* Fri Dec  7 2018 tchvatal@suse.com
- Update to 4.6.5:
  * Many many changes everywhere, see CHANGELOG.md for details
- Use github tarball to include license/tests
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Wed Oct 10 2018 dmueller@suse.com
- cleanup filelist
* Tue Oct  9 2018 comurphy@suse.com
- Replace python-pycryptodomex dep with python-cryptography
  - Dependency was swapped in afdf5b4
* Wed Nov 29 2017 okurz@suse.com
- Add missing runtime dependency on 'defusedxml'
- Add obsolete suse_version special handling
* Mon Oct 30 2017 michael@stroeder.com
- update to 4.5.0
* Mon Jun 19 2017 okurz@suse.com
- Convert to singlespec
* Tue Nov 22 2016 dmueller@suse.com
- fix requires
* Thu Nov 17 2016 michael@stroeder.com
- update to 4.4.0
- added LICENSE.txt to docs
* Fri Feb 26 2016 tbechtold@suse.com
- Require python-python-dateutil. package was renamed
* Tue Oct 13 2015 dmueller@suse.com
- add pycrypto/pyOpenSSL dependency
* Tue Sep  1 2015 tbechtold@suse.com
- Move python-repoze.who from Recommends to Requires. It's needed.
* Thu Jul 30 2015 tbechtold@suse.com
- Add missing Requires
* Thu Jul 16 2015 seife+obs@b1-systems.com
- fix build on non-SUSE distributions whose rpm does not know
  "Recommends"
* Wed Jun 10 2015 dmueller@suse.com
- update to 2.4.0:
  * A couple of security fixes plus maintenance updates.
* Tue Oct 15 2013 speilicke@suse.com
- Initial version
